#
# spec file for package csmash
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           csmash
Version:        0.6.6
Release:        274.7
Summary:        3D Table Tennis Game
License:        GPL-2.0-or-later
Group:          Amusements/Games/3D/Other
URL:            http://cannonsmash.sourceforge.net/
Source:         %{name}-%{version}.tar.bz2
Source1:        danslatristesse2-48.ogg
Source2:        %{name}.desktop
Patch0:         %{name}-%{version}.diff
Patch1:         %{name}-%{version}-datadir.diff
Patch2:         %{name}-%{version}-return_value.diff
Patch3:         %{name}-%{version}-qualification.diff
Patch4:         %{name}-%{version}-definitions.diff
Patch5:         %{name}-%{version}-uninitialized.diff
BuildRequires:  SDL_image-devel
BuildRequires:  SDL_mixer-devel
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk+-x11-2.0)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(zlib)

%description
CannonSmash is a 3D table tennis game. The goal of this project is to
represent various table tennis strategies in a computer game.

%prep
%autosetup -p0
mv README README.jp
mv README.en README

%build
%configure \
  --x-includes=%{_includedir} \
  --x-libraries=%{_libdir}
%make_build AM_CFLAGS="%optflags" AM_CPPFLAGS="%optflags"

%install
%make_install
cp %{SOURCE1} %{buildroot}%{_datadir}/csmash
%fdupes %{buildroot}%{_datadir}
desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}
%find_lang %{name}

%files -f %{name}.lang
%doc README README.jp AUTHORS COPYING CREDITS ChangeLog
%{_bindir}/csmash
%{_datadir}/csmash/
%{_datadir}/applications/%{name}.desktop

%changelog
* Thu May 19 2022 Jan Engelhardt <jengelh@inai.de>
- Build with to pkgconfig(sdl) so we can use sdl12_compat.
* Mon Jun  4 2018 meissner@suse.com
- build with RPM_OPT_FLAGS
* Fri Feb  9 2018 crrodriguez@opensuse.org
- FIx buildRequires so metapackages xorg-x11-devel, Mesa-devel
  are not required anymore.
* Tue Sep 18 2012 idonmez@suse.com
- Add explicit glu dependency
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Mon Nov  8 2010 prusnak@opensuse.org
- spec cleanup
* Mon Nov  8 2010 coolo@novell.com
- remove support for pre-9.1
* Sat Jan  2 2010 vuntz@opensuse.org
- Change gtk1-compat-devel BuildRequires to gtk2-devel: the game
  has been ported to GTK+ 2 a while ago.
- Make sure to use datadir instead of /usr/share.
* Mon Nov 12 2007 lmichnovic@suse.cz
- using find_lang macro
- fixed uninitilized variable (uninitialized.diff)
* Fri Nov  9 2007 lmichnovic@suse.cz
- using fdupes macro
- not installing files INSTALL, NEWS (zero lenght)
- renamed last patch to *definitions.diff
* Thu Oct 25 2007 pgajdos@suse.cz
- fixed build with new gcc 4.3
* Fri Mar 23 2007 lmichnovic@suse.cz
- forcing use of CXXFLAGS for compilation
* Mon Aug  7 2006 lmichnovic@suse.cz
- using gettextize -f to fix not expanding macro MKINSTALLDIRS
* Fri Jul 28 2006 lmichnovic@suse.cz
- checking version of X.org instead of suse_version
* Mon Jul 24 2006 lmichnovic@suse.cz
- fixed new X.org 7.x includes and headers dir
- now using aclocal, automake, autoconf
- using make %%{?jobs:-j%%jobs} for icecream
* Fri Jan 27 2006 nadvornik@suse.cz
- fixed BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Oct 20 2005 lmichnovic@suse.cz
- fixed invalid extra qualification for build with new gcc 4.1
* Mon Oct 10 2005 lmichnovic@suse.cz
- upgrade to version 0.6.6
- now building as gtk2 application
* Sat Jan 10 2004 adrian@suse.de
- add %%defattr
* Tue Aug 12 2003 ltinkl@suse.cz
- fixed bug #28657 (wrong datadir)
* Mon Aug 11 2003 sndirsch@suse.de
- added desktop file
* Fri Jul 11 2003 ltinkl@suse.cz
- updated to version 0.6.5
- install binary to /usr/bin and data to /usr/share
* Mon Jun  2 2003 ro@suse.de
- added translations to filelist
* Tue Sep  3 2002 ro@suse.de
- fix compilation (object->name may not be passed though ...)
* Wed Jul 31 2002 uli@suse.de
- fixed to build on 64 bit archs
* Tue Jul 30 2002 tcrhak@suse.cz
- update to version 0.6.4.2
* Tue Nov 13 2001 tcrhak@suse.cz
- removed aclocal, autoconf and automake
* Thu Nov  8 2001 ro@suse.de
- use mesa-devel-packages in neededforbuild
* Thu Oct 18 2001 tiwai@suse.de
- updated to version 0.6.3.
- added smpeg and smpeg-devel to neededforbuild.
* Wed Oct 17 2001 schwab@suse.de
- Fix for gcc 3.
* Mon Sep  3 2001 tiwai@suse.de
- updated to version 0.6.2
  (better graphics, bug fixes, opening BGM).
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <kdelibs kdelibs-devel> to <kdelibs-artsd>
* Wed Aug  8 2001 ro@suse.de
- changed neededforbuild <sdl> to <SDL>
- changed neededforbuild <sdl-devel> to <SDL-devel>
* Mon Jul 30 2001 dan@suse.cz
- 0.6.1 version
* Wed Jun 20 2001 ro@suse.de
- added kdelibs for arts
* Sat May  5 2001 sndirsch@suse.de
- replaced glx with mesasoft in #neededforbuild
* Sat Apr 14 2001 schwab@suse.de
- Add alsa to neededforbuild.
* Fri Apr 13 2001 pblaha@suse.cz
- update on 0.6.0
* Thu Mar 15 2001 ro@suse.de
- changed neededforbuild <mesaglu> to <xf86glu>
- changed neededforbuild <mesaglu-devel> to <xf86glu-devel>
* Thu Mar  8 2001 uli@suse.de
- added mesaglu*, mesaglut* to neededforbuild
* Wed Mar  7 2001 ro@suse.de
- changed neededforbuild <mesadev> to <mesa-devel>
* Wed Dec 20 2000 pblaha@suse.cz
- create this package
